# Generated by Django 3.2.5 on 2023-02-02 08:46

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='PlatformsToUsers',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('platform_user_id', models.BigIntegerField(blank=True, db_index=True, null=True, verbose_name='平台用户ID')),
            ],
            options={
                'verbose_name_plural': '09. 用户 - 多对多平台记录表',
                'db_table': 'user_platforms_to_users',
                'managed': False,
            },
        ),
    ]
